package com.cr.hrecloud.cloud;

import com.alibaba.fastjson.JSONObject;
import com.cr.hrecloud.HttpUtil;
import com.cr.hrecloud.cloud.HrConfig;
import com.rsa.RSASignature;
import com.rsa.RSAUtil;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Map;
import java.util.Random;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class HrECloudHelper {

   private static final Logger LOGGER = LoggerFactory.getLogger(HrECloudHelper.class);
   private static String dataPublicKey = "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCFZnUVz07wuQfI5kf3uOaaJcpq*W3yQhJnIX2k-EKwKZaSkyuXutk0TXqwT-GXxIQJqmkjLup*HN7H1uF7JMfxl00AnncHB82LqUQKQwf5wcdDTNhvKLQtjRoLE3ry6ARoYHu5AkZPKW7sMM4o*UegPlSr45p4ZsK0iVdjqmgZfwIDAQAB";
   private static String signPrivateKey = "MIICeAIBADANBgkqhkiG9w0BAQEFAASCAmIwggJeAgEAAoGBAKOoelzwAU5Asw9zknkTYGvfZr0Ap6ZDL6NMSNRYZ2maVJd5xOfSRqTkEq1Ne*h2Qe3wCKdxo0SuCVWNjM-nd3af*fb4YcWdlDuHaA1s28I5hZtVp2sbF*nvgdeUwSz-X0hQGcaqVzcTKDH9l2XuMC**OEofyyosU2jvEIGdwqSNAgMBAAECgYAkojvxvc*tApKSbN5mt82nl-RZbmIYt4VcWmEbF0bevqsc1SccdVdW5a7AmE2aNY6AgnCNesR-RS3Vtr-Ech2tVfwMXypJsXN5hq0uyM6iDkE6kFhGL1zui72u9RQJvdB7CsNfEONIaFlX46MUOdF0fR2n-sGLMc1qzpj*L3k6QQJBAOJfQRF6ehE5d1Sm*7q9uObte1ubako89TSGZmCOk-3vpm9CRTey-18Ids98yMNg3Wy53M4oEzjwjdnnulX9PpUCQQC5E-NySYbigVCsO5Tjr*iAA1ykdGIgaRM45s2tvbMLYQdZYhnkPRjSj*Y7I915cp5klQ75T260InPYQqBkb2gZAkEAjRYtKcWZ*s5EL4B7eCHy8gqlTa0JjAd*FCSH-joexq-snX9CQLrRKtvNoPf28L6YgsE8e0jC4kQbROqGWj2iGQJBAKkXVUCBdL7UrsPs26b6PE1YxPdrbYt29Jz0Ic4ulro6t*AuBMHGIDugRRSbO*mNkrEKjlew-s*M*pIGrUuVjWECQQC3qMemXCmqp7lAaSqYy9Rk8HNVgEeDqJfhcIS4SrRH0DSExPE9yfhadaiC4IIYmmK5L*2V3dxIUI7KXbeO*ptz";
   private static HrConfig hrConfig;


   public static void setHrConfig(HrConfig config) {
      hrConfig = config;
   }

   public static HrConfig getHrConfig() {
      if(hrConfig == null) {
         throw new IllegalArgumentException("setHrConfig()必须先被调用");
      } else {
         return hrConfig;
      }
   }

   private static JSONObject encryptReqData(HrConfig config, String data, String busiCode) {
      JSONObject request = new JSONObject();
      String encryptData = RSAUtil.encrypt(data, dataPublicKey);
      request.put("data", encryptData);
      String signData = RSASignature.sign(data, signPrivateKey);
      request.put("sign", signData);
      request.put("assurerNo", config.getAssurerNo());
      request.put("bankType", config.getBankType());
      request.put("busiCode", busiCode);
      request.put("platNo", config.getPlatNo());
      request.put("bankCode", config.getBankCode());
      return request;
   }

   public static String readFile(File file) throws Exception {
      BufferedReader reader = null;
      StringBuffer buffer = new StringBuffer();

      try {
         reader = new BufferedReader(new InputStreamReader(new FileInputStream(file), "utf-8"));
         String e = "";

         while((e = reader.readLine()) != null) {
            buffer.append(e);
            buffer.append("\n");
         }
      } catch (IOException var11) {
         throw var11;
      } finally {
         if(reader != null) {
            try {
               reader.close();
            } catch (Exception var10) {
               ;
            }
         }

      }

      return buffer.toString();
   }

   private static JSONObject readDemoConfig(String relPath, HrConfig config) throws Exception {
      String str = readFile(new File(System.getProperty("user.dir") + "/demoConfig/" + relPath));
      JSONObject json = JSONObject.parseObject(str);
      JSONObject pub = json.getJSONObject("pub");
      String oldOrderNo = pub.getString("orderNo");
      if(oldOrderNo == null || !oldOrderNo.startsWith("zrtest")) {
         pub.put("orderNo", "zrtest" + System.currentTimeMillis() + "r" + (new Random()).nextInt());
      }

      pub.put("bankCode", config.getBankCode());
      pub.put("assurerNo", config.getAssurerNo());
      pub.put("platNo", config.getPlatNo());
      pub.put("bankType", config.getBankType());
      pub.put("productType", config.getProductType());
      return json;
   }

   public static JSONObject demoApiTest(String title, String relPath, String busiCode, Map extra) throws Exception {
      setHrConfig(HrConfig.getDemoConfig());
      System.out.println("====== start =====\n测试 " + title + ", relPath=" + relPath + ", busiCode=" + busiCode);
      JSONObject data = readDemoConfig(relPath, HrConfig.getDemoConfig());
      System.out.println("订单号: " + data.getJSONObject("pub").get("orderNo"));
      long startT = System.currentTimeMillis();
      JSONObject ret = hrPost(data.toString(), busiCode);
      long endT = System.currentTimeMillis();
      System.out.println("用时 " + (endT - startT) + " 毫秒，返回值：");
      System.out.println(ret);
      System.out.println("====== end ==========");
      JSONObject demoRet = new JSONObject();
      demoRet.put("request", data);
      demoRet.put("response", ret);
      return demoRet;
   }

   public static JSONObject hrPost(HrConfig config, String data, String busiCode) {
      LOGGER.info("HrPost Request busiCode=" + busiCode + ", config=" + JSONObject.toJSONString(config) + ", data=" + data);
      JSONObject json = encryptReqData(config, data, busiCode);
      LOGGER.info("HrPost Request busiCode=" + busiCode + ", encrypt=" + JSONObject.toJSONString(json));
      JSONObject response = HttpUtil.doPost(config.getRequestUrl(), json);
      LOGGER.info("HrPost Response busiCode=" + busiCode + ", response=" + response.toJSONString());
      return response;
   }

   public static JSONObject hrPost(String data, String busiCode) {
      return hrPost(getHrConfig(), data, busiCode);
   }

   public static JSONObject cardApply(String data) {
      return hrPost(data, "1003");
   }

   public static JSONObject creditApply(String data) {
      return hrPost(data, "1001");
   }

   public static JSONObject stageApply(String data) {
      return hrPost(data, "1002");
   }

   public static JSONObject supplyment(String data) {
      return hrPost(data, "1005");
   }

   public static void main(String[] args) throws Exception {
      String data = "hkhkjk";
      String encryptData = RSAUtil.encrypt(data, dataPublicKey);
      String signData = RSASignature.sign(data, signPrivateKey);
      System.out.println("encrypt: \n" + encryptData);
      System.out.println("sign: \n" + signData);
   }

}
